==> rpx_1.20.2.zip: rpx/NEWS.md <==
# rpx 1.20

## rpx 1.20.2
- Temporary fix for issue #5 (wrong URL from PRIDE server)
  <2019-10-02 Wed>

## rpx 1.20.1
- Don't set old class <2019-08-09 Fri>

# rpx 1.19

## rpx 1.19.4
- Delete plain NEWS now that R supports NEWS.md

## rpx 1.19.3
- Fix NEWS

## rpx 1.19.2
- Mention setting `method` on Windows <2019-04-16 Tue>

## rpx 1.19.1
- Add ImmunoOncology biocView

## rpx 1.19.0
- New release for Bioc 3.9

# rpx 1.18

## rpx 1.18.0
- New release for Bioc 3.8

# rpx 1.17

## CHANGES IN VERSION 1.17.2
- Update NEWS and pkgdown site

## CHANGES IN VERSION 1.17.1
- replace BiocInstaller biocLite mentions with BiocManager

## CHANGES IN VERSION 1.17.0
- New version for Bioconductor devel

# rpx 1.16

## CHANGES IN VERSION 1.16.0
- New version for Bioconductor release

# rpx 1.13

## CHANGES IN VERSION 1.13.5

- Nothing yet

## CHANGES IN VERSION 1.13.4

- Restore reference unit test

## CHANGES IN VERSION 1.13.3

- No commit

## CHANGES IN VERSION 1.13.2

- Fix errors due to changes on PX side. PXD000001 reference remains
  untested - see https://twitter.com/lgatt0/status/885091284142239744
  for details. <2017-07-12 Wed>

## CHANGES IN VERSION 1.13.1

- Using xml2 <2017-06-13 Tue>
- Use functions instead of methods <2017-06-13 Tue>

## CHANGES IN VERSION 1.13.0

- Bioc devel 3.6

# rpx 1.12

## CHANGES IN VERSION 1.12.1

- Using xml2 (backported from devel) <2017-06-13 Tue>
- Use functions instead of methods (backported from devel) <2017-06-13 Tue>

## CHANGES IN VERSION 1.12.0

- Bioc release 3.5

# rpx 1.11

## CHANGES IN VERSION 1.11.0

- Bioc devel 3.4

## CHANGES IN VERSION 1.11.4

- Update unit test to reflect upstream changes <2017-02-26 Sun>

## CHANGES IN VERSION 1.11.3

- `pxget` gains a `destdir` argument to specify the destination to which files
	should be downloaded <2017-01-27 Fri>

## CHANGES IN VERSION 1.11.2

- Update unit test to reflect upstream changes <2017-01-25 Wed>

## CHANGES IN VERSION 1.11.1

- Migrate vignette to BiocStyle::html_document2 <2016-12-22 Thu>
- Use NEWS.md <2016-12-28 Wed>

## CHANGES IN VERSION 1.11.0

- Bioconductor devel 3.5

# rpx 1.10

## CHANGES IN VERSION 1.10.0

- Bioconductor release 3.4

# rpx 1.9

## CHANGES IN VERSION 1.9.4

- Updating unit tests <2016-10-04 Tue>

## CHANGES IN VERSION 1.9.3

- Update vignette to use readMzTabData v0.9 <2016-07-24 Sun>

# rpx 1.5

## CHANGES IN VERSION 1.5.1

- unit tests <2015-06-30 Tue>
- export and document pxnodes <2015-06-30 Tue>

## CHANGES IN VERSION 1.5.0

- Bioc version 3.2 (devel)

# rpx 1.4

## CHANGES IN VERSION 1.4.0

- Bioc version 3.1 (release)

# rpx 1.3

## CHANGES IN VERSION 1.3.1

- update vignette to reflect new files in px example, and avoid
  downloaded the raw data [2015-03-31 Tue]

# rpx 0.99

## CHANGES IN VERSION 0.99.9

- In pxref, dealing with cases without any-r pending publications
   [2014-04-01 Tue]

## CHANGES IN VERSION 0.99.8

- fix leftover issues from renaming package (d.tenenbaum)
   [2014-03-30 Sun]

## CHANGES IN VERSION 0.99.7

- renamed to rpx due to CRAN name clash [2014-03-28]

## CHANGES IN VERSION 0.99.6

- more typos in vignette [2014-03-12 Wed]

## CHANGES IN VERSION 0.99.5

- Suggestions, biocView and typos reported by Nate Hayden
   [2014-03-12 Wed]
- added Runit test [2014-03-12 Wed]
- use ae fonts in vignette [2014-03-12 Wed]

## CHANGES IN VERSION 0.99.4

- Update reference in man and vignette [2014-03-11 Tue]
- Typos in vignette [2014-03-11 Tue]

## CHANGES IN VERSION 0.99.3

- reverting pxannounced to empty signature to fix warning
 [2014-03-05 Wed]

## CHANGES IN VERSION 0.99.2

- replacing download.file by getURL to download annoucement rss-ver
   https <2014-03-05 Wed>

## CHANGES IN VERSION 0.99.1

- fixing pxfiles ending by \r-n Windows [2014-03-05 Wed]

## CHANGES IN VERSION 0.99.0

- added a vignette [2014-03-05 Wed]
- handle invalid identifiers [2014-03-05 Wed]

==> rpx_1.22.0.zip: rpx/NEWS.md <==
# rpx 1.21

## Changes in version 1.21.3
- Update NEWS titles

## Changes in version 1.21.2
- Temporary fix for issue #5 (wrong URL from PRIDE server)
  <2019-10-02 Wed>

## Changes in version 1.21.1
- Don't set old class <2019-08-09 Fri>

# rpx 1.19

## Changes in version 1.19.4
- Delete plain NEWS now that R supports NEWS.md

## Changes in version 1.19.3
- Fix NEWS

## Changes in version 1.19.2
- Mention setting `method` on Windows <2019-04-16 Tue>

## Changes in version 1.19.1
- Add ImmunoOncology biocView

## Changes in version 1.19.0
- New release for Bioc 3.9

# rpx 1.18

## Changes in version 1.18.0
- New release for Bioc 3.8

# rpx 1.17

## Changes in version 1.17.2
- Update NEWS and pkgdown site

## Changes in version 1.17.1
- replace BiocInstaller biocLite mentions with BiocManager

## Changes in version 1.17.0
- New version for Bioconductor devel

# rpx 1.16

## Changes in version 1.16.0
- New version for Bioconductor release

# rpx 1.13

## Changes in version 1.13.5

- Nothing yet

## Changes in version 1.13.4

- Restore reference unit test

## Changes in version 1.13.3

- No commit

## Changes in version 1.13.2

- Fix errors due to changes on PX side. PXD000001 reference remains
  untested - see https://twitter.com/lgatt0/status/885091284142239744
  for details. <2017-07-12 Wed>

## Changes in version 1.13.1

- Using xml2 <2017-06-13 Tue>
- Use functions instead of methods <2017-06-13 Tue>

## Changes in version 1.13.0

- Bioc devel 3.6

# rpx 1.12

## Changes in version 1.12.1

- Using xml2 (backported from devel) <2017-06-13 Tue>
- Use functions instead of methods (backported from devel) <2017-06-13 Tue>

## Changes in version 1.12.0

- Bioc release 3.5

# rpx 1.11

## Changes in version 1.11.0

- Bioc devel 3.4

## Changes in version 1.11.4

- Update unit test to reflect upstream changes <2017-02-26 Sun>

## Changes in version 1.11.3

- `pxget` gains a `destdir` argument to specify the destination to which files
	should be downloaded <2017-01-27 Fri>

## Changes in version 1.11.2

- Update unit test to reflect upstream changes <2017-01-25 Wed>

## Changes in version 1.11.1

- Migrate vignette to BiocStyle::html_document2 <2016-12-22 Thu>
- Use NEWS.md <2016-12-28 Wed>

## Changes in version 1.11.0

- Bioconductor devel 3.5

# rpx 1.10

## Changes in version 1.10.0

- Bioconductor release 3.4

# rpx 1.9

## Changes in version 1.9.4

- Updating unit tests <2016-10-04 Tue>

## Changes in version 1.9.3

- Update vignette to use readMzTabData v0.9 <2016-07-24 Sun>

# rpx 1.5

## Changes in version 1.5.1

- unit tests <2015-06-30 Tue>
- export and document pxnodes <2015-06-30 Tue>

## Changes in version 1.5.0

- Bioc version 3.2 (devel)

# rpx 1.4

## Changes in version 1.4.0

- Bioc version 3.1 (release)

# rpx 1.3

## Changes in version 1.3.1

- update vignette to reflect new files in px example, and avoid
  downloaded the raw data [2015-03-31 Tue]

# rpx 0.99

## Changes in version 0.99.9

- In pxref, dealing with cases without any-r pending publications
   [2014-04-01 Tue]

## Changes in version 0.99.8

- fix leftover issues from renaming package (d.tenenbaum)
   [2014-03-30 Sun]

## Changes in version 0.99.7

- renamed to rpx due to CRAN name clash [2014-03-28]

## Changes in version 0.99.6

- more typos in vignette [2014-03-12 Wed]

## Changes in version 0.99.5

- Suggestions, biocView and typos reported by Nate Hayden
   [2014-03-12 Wed]
- added Runit test [2014-03-12 Wed]
- use ae fonts in vignette [2014-03-12 Wed]

## Changes in version 0.99.4

- Update reference in man and vignette [2014-03-11 Tue]
- Typos in vignette [2014-03-11 Tue]

## Changes in version 0.99.3

- reverting pxannounced to empty signature to fix warning
 [2014-03-05 Wed]

## Changes in version 0.99.2

- replacing download.file by getURL to download annoucement rss-ver
   https <2014-03-05 Wed>

## Changes in version 0.99.1

- fixing pxfiles ending by \r-n Windows [2014-03-05 Wed]

## Changes in version 0.99.0

- added a vignette [2014-03-05 Wed]
- handle invalid identifiers [2014-03-05 Wed]
